
local function toProtoTimestamp(timestampInSeconds)
  -- Protobuf 64-bit numbers are serialized as strings.
  -- See https://developers.google.com/protocol-buffers/docs/proto3#json
  return string.format("%.0f", math.floor(1.0e6 * timestampInSeconds))
end

local function startsWith(str, start)
   return str:sub(1, #start) == start
end

local function flattenHeaderArray(values)
  local result = ""
  for index, value in ipairs(values) do
    if index > 1 then
      result = result .. "," .. value
    else
      result = value
    end
  end
  return result
end

local function isTracePropagationHeader(key)
  return startsWith(key, "x-b3-") or
         key == "traceparent" or
         key == "tracestate"
end

return {
  toProtoTimestamp = toProtoTimestamp,
  startsWith = startsWith,
  flattenHeaderArray = flattenHeaderArray,
  isTracePropagationHeader = isTracePropagationHeader,
}
